@@ -4,27 +4,17 @@
 #'    given \bold{equal-length arrays} of search model parameters: mu, lambda, nu and 
 #'    zeta1.
 #' 
-#' @param mu Array: the mean of the Gaussian distribution for the 
-#'    ratings of latent LLs (continuous ratings of lesions that are found by the 
-#'    observer's search mechanism). The ratings of NLs are distributed as N(0,1).
+#' @param mu Array: the RSM mu parameter.
 #' 
-#' @param lambda Array: the \emph{intrinsic} Poisson distribution parameter 
-#'    which models the random numbers of latent NLs (suspicious regions that do 
-#'    not correspond to actual lesions) per case. The corresponding 
-#'    \emph{physical} parameter is \code{lambda/mu}. Two conversion functions 
-#'    are provided: \code{\link{UtilIntrinsic2PhysicalRSM}} and 
-#'    \code{\link{UtilPhysical2IntrinsicRSM}}.
+#' @param lambda Array: the RSM lambda parameter.
 #' 
-#' @param nu Array: the \emph{intrinsic} parameter which models the random 
-#'    numbers of latent LLs (suspicious regions that correspond to actual 
-#'    lesions) per diseased case. The corresponding \emph{physical} parameter is 
-#'    \code{1 - exp(nu*mu)}, the success probability of the binomial distribution.
+#' @param nu Array: the RSM nu parameter.
 #' 
 #' @param zeta1 Array, the lowest reporting threshold; if missing the default 
 #'    is an array of -3s. 
 #'
 #' @param lesDistr Array: the probability mass function of the 
-#'    lesion distribution for diseased cases. See \link{UtilLesionDistrVector}. 
+#'    lesion distribution for diseased cases. The default is 1. See \link{UtilLesionDistrVector}. 
 #' 
 #' @param relWeights The relative weights of the lesions; a vector of 
 #'    length equal to \code{length(maxLL)}. The default is zero, in which case
@@ -53,7 +43,7 @@
 #' 
 #' @param nlfAlpha Upper limit of the integrated area under the FROC plot. 
 #'    Default is "\code{NULL}", which means the maximum NLF range is used 
-#'    (i.e., lambda/mu). Attempt to integrate outside the maximum NLF will 
+#'    (i.e., lambda). Attempt to integrate outside the maximum NLF will 
 #'    generate an error.
 #' 
 #' 
@@ -105,10 +95,9 @@
 #' ## mu = 3, lambda = 1.5, nu = 0.8, in the other treatment. 20% of the diseased 
 #' ## cases have a single lesion, 40% have two lesions, 10% have 3 lesions, 
 #' ## and 30% have 4 lesions.  
-#' lesDistr <- c(0.2, 0.4, 0.1, 0.3)
 #' 
 #' PlotRsmOperatingCharacteristics(mu = c(2, 3), lambda = c(1, 1.5), nu = c(0.6, 0.8),
-#'    lesDistr = lesDistr, legendPosition = "bottom", nlfRange = c(0, 1), llfRange = c(0, 1))
+#'    lesDistr = c(0.2, 0.4, 0.1, 0.3), legendPosition = "bottom")
 #' 
 #' @export
 #' 
@@ -116,7 +105,7 @@ PlotRsmOperatingCharacteristics <- function(mu,
                                             lambda, 
                                             nu,
                                             zeta1,
-                                            lesDistr, 
+                                            lesDistr = 1, 
                                             relWeights = 0, 
                                             OpChType = "ALL", 
                                             legendPosition = c(1,0), 
@@ -156,25 +145,22 @@ PlotRsmOperatingCharacteristics <- function(mu,
   wAFROCDashes <- data.frame(FPF = NULL, wLLF= NULL, Treatment = NULL, stringsAsFactors = FALSE)
   abnPDFPoints <- data.frame(pdf = NULL, highestZSample = NULL, Treatment = NULL, stringsAsFactors = FALSE)
   norPDFPoints <- data.frame(pdf = NULL, highestZSample = NULL, Treatment = NULL, stringsAsFactors = FALSE)
-  aucROC <- rep(NA, length(mu));aucAFROC <- aucROC;aucwAFROC <- aucROC;aucFROC <- aucROC;lambdaP <- lambda
-  nuP <- nu
+  aucROC <- rep(NA, length(mu));aucAFROC <- aucROC;aucwAFROC <- aucROC;aucFROC <- aucROC
   
   for (i in 1:length(mu)){
     if (mu[i] <= 0 ) stop("mu must be greater than zero")
     if (lambda[i] < 0 ) stop("lambda must be greater than zero")
     if (nu[i] < 0 ) stop("nu must be greater than zero")
-    x <- UtilIntrinsic2PhysicalRSM(mu[i], lambda[i], nu[i])
-    lambdaP <- x$lambdaP
-    nuP <- x$nuP
-    FPF <- sapply(zeta[[i]], xROC, lambdaP = lambdaP) # C++ function uses lambdaP
-    TPF <- sapply(zeta[[i]], yROC, mu = mu[i], lambdaP = lambdaP, nuP = nuP, lesDistr = lesDistr)
-    NLF <- sapply(zeta[[i]], RSM_xFROC, lambda = lambdaP)
-    LLF <- sapply(zeta[[i]], RSM_yFROC, mu = mu[i], nu = nuP)
+    
+    FPF <- sapply(zeta[[i]], xROC, lambda[i]) # C++ function uses lambda
+    TPF <- sapply(zeta[[i]], yROC, mu = mu[i], lambda[i], nu[i], lesDistr)
+    NLF <- sapply(zeta[[i]], RSM_NLF, lambda[i])
+    LLF <- sapply(zeta[[i]], RSM_LLF, mu = mu[i], nu[i]) # 9/22/22
 # begin bug fix
 # found bug 11/24/21 two places, here and as indicated by # bug fix 11/24/21
 # found ROC AUC did not change with zeta1 as it should   
-#    maxFPF <- xROC(-20, lambdaP[i]) # this is wrong
-    maxFPF <- xROC(zeta1[i], lambdaP) # this is correct
+#    maxFPF <- xROC(-20, lambda[i]) # this is wrong
+    maxFPF <- xROC(zeta1[i], lambda[i]) # this is correct
     if( OpChType == "ALL" ||  OpChType == "ROC"){
       ROCPoints <- rbind(ROCPoints, data.frame(FPF = FPF, 
                                                TPF = TPF, 
@@ -184,10 +170,10 @@ PlotRsmOperatingCharacteristics <- function(mu,
                                                TPF = c(TPF[1], 1), 
                                                Treatment = as.character(i), 
                                                stringsAsFactors = FALSE))
-#       maxTPF <- yROC(-20, mu[i], lambdaP, nuP, lesDistr)
-      maxTPF <- yROC(zeta1[i], mu[i], lambdaP, nuP, lesDistr)
+#       maxTPF <- yROC(-20, mu[i], lambda, nu, lesDistr)
+      maxTPF <- yROC(zeta1[i], mu[i], lambda[i], nu[i], lesDistr)
 # end bug fix
-      AUC <- integrate(y_ROC_FPF, 0, maxFPF, mu = mu[i], lambdaP = lambdaP, nuP = nuP, lesDistr =lesDistr)$value
+      AUC <- integrate(y_ROC_FPF, 0, maxFPF, mu = mu[i], lambda[i], nu[i], lesDistr =lesDistr)$value
       aucROC[i] <- AUC + (1 + maxTPF) * (1 - maxFPF) / 2
     }
     
@@ -198,11 +184,11 @@ PlotRsmOperatingCharacteristics <- function(mu,
                                                  stringsAsFactors = FALSE))
       if (is.null(nlfAlpha)){
         maxNLF <- max(NLF)
-        aucFROC[i] <- integrate(intFROC, 0, maxNLF, mu= mu[i], lambda = lambdaP, nu = nuP)$value
+        aucFROC[i] <- integrate(integrandFROC, 0, maxNLF, mu= mu[i], lambda[i], nu[i])$value
       }else{
         maxNLF <- max(NLF)
         if (nlfAlpha <= maxNLF){
-          aucFROC[i] <- integrate(intFROC, 0, nlfAlpha, mu= mu[i], lambda = lambdaP, nu = nuP)$value
+          aucFROC[i] <- integrate(integrandFROC, 0, nlfAlpha, mu= mu[i], lambda[i], nu[i])$value
         }else{
           stop("nlfAlpha cannot be greater than the maximum of NLF.")
         }
@@ -218,13 +204,13 @@ PlotRsmOperatingCharacteristics <- function(mu,
                                                    LLF = c(LLF[1], 1), 
                                                    Treatment = as.character(i), 
                                                    stringsAsFactors = FALSE))
-      maxLLF <- RSM_yFROC(zeta1[i], mu[i], nu[i]) # bug fix 11/24/21
-      AUC <- integrate(y_AFROC_FPF, 0, maxFPF, mu = mu[i], lambda = lambdaP, nu = nuP)$value
+      maxLLF <- RSM_LLF(zeta1[i], mu[i], nu[i]) # bug fix 9/22/22
+      AUC <- integrate(y_AFROC_FPF, 0, maxFPF, mu = mu[i], lambda[i], nu[i])$value
       aucAFROC[i] <- AUC + (1 + maxLLF) * (1 - maxFPF) / 2
     }
     
     if( OpChType == "ALL" ||  OpChType == "wAFROC"){
-      wLLF <- sapply(zeta[[i]], ywAFROC, mu[i], nuP, lesDistr, lesWghtDistr)
+      wLLF <- sapply(zeta[[i]], ywAFROC, mu[i], nu[i], lesDistr, lesWghtDistr) # cpp code requires lesWghtDistr
       wAFROCPoints <- rbind(wAFROCPoints, data.frame(FPF = FPF, 
                                                      wLLF = wLLF, 
                                                      Treatment = as.character(i), 
@@ -233,8 +219,9 @@ PlotRsmOperatingCharacteristics <- function(mu,
                                                      wLLF = c(wLLF[1], 1), 
                                                      Treatment = as.character(i), 
                                                      stringsAsFactors = FALSE))
-      maxWLLF <- ywAFROC(zeta1[i], mu[i], nuP, lesDistr, lesWghtDistr) # bug fix 11/24/21
-      AUC <- integrate(y_wAFROC_FPF, 0, maxFPF, mu = mu[i], lambda = lambdaP, nu = nuP, lesDistr, lesWghtDistr)$value
+      # maxWLLF <- ywAFROC(zeta1[i], mu[i], nu[i], lesDistr, lesWghtDistr) # bug fix 11/24/21
+      maxWLLF <- RSM_wLLF(zeta1[i], mu[i], nu[i], lesDistr, relWeights) # bug fix 11/24/21
+      AUC <- integrate(y_wAFROC_FPF, 0, maxFPF, mu = mu[i], lambda[i], nu[i], lesDistr, relWeights)$value
       aucwAFROC[i] <- AUC + (1 + maxWLLF) * (1 - maxFPF) / 2
     }
     
